@@ -3,7 +3,6 @@ module Lambdabot.Plugin.Misc
     , errorPlugin
     , freshPlugin
     , helloPlugin
-    , statsPlugin
     , todoPlugin
     
     , miscPlugins
@@ -13,7 +12,6 @@ import Lambdabot.Plugin.Misc.Dummy
 import Lambdabot.Plugin.Misc.Error
 import Lambdabot.Plugin.Misc.Fresh
 import Lambdabot.Plugin.Misc.Hello
-import Lambdabot.Plugin.Misc.Stats
 import Lambdabot.Plugin.Misc.Todo
 
 miscPlugins :: [String]
